#!/usr/bin/env bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

set -o errexit -o nounset

function usage {
    echo "Usage: load_test [test_count]

    This script load tests the workspaces capability service by creating and submitting
    the specified number of null requests to the system under testing.
    Running this on the production system is not recommended.
    "
}

test_count=$1

CAPABILITY_SERVICE=$(capo -q edu.nrao.workspaces.CapabilitySettings.externalServiceUrl)

parameters="{\"parameters\": {\"arguments\": \"-g\"}}"

for i in $(seq "$test_count");do
  curl --header "Content-Type: application/json" --request POST --data "$parameters" "$CAPABILITY_SERVICE"/capability/null/request/create-and-submit &
done

echo "All $test_count requests submitted for Load Test.
Please use the active requests page or the database to monitor the progress of these requests."
